==> campsite-2.4.1.tar.gz: campsite/implementation/management/priv/lang/ro/user_types.php <==
<?php
regGS("User types", "Tipuri de utilizatori");
regGS("No user types.", "Nu există tipuri de utilizatori");
regGS("You do not have the right to add user types.", "Nu aveţi dreptul să adăugaţi tipuri de utilizatori");
regGS("Adding new user type", "Adaug tip de utilizator");
regGS("The user type $1 has been added.", "Tipul de utilizator $1 a fost adăugat");
regGS("The user type could not be added.", "Tipul de utilizator $1 nu poate fi adăugat");
regGS("Please check if an user type with the same name does not already exist.", "Verificaţi dacă tipul de utilizator există deja");
regGS("Are you sure you want to delete the user type $1?", "Doriţi să ştergeţi tipul de utilizator $1?");
regGS("No such user type.", "Nu există tipul de utilizator");
regGS("Deleting user type", "Şterg tipul de utilizator");
regGS("You do not have the right to delete user types.", "Nu aveţi dreptul să ştergeţi tipuri de utilizatori");
regGS("The user type has been deleted.", "Tipul de utilizator a fost şters");
regGS("The user type could not be deleted.", "Tipul de utilizator nu poate fi şters");
regGS("Change user type permissions", "Modifică drepturile tipului de utilizator");
regGS("You do not have the right to change user type permissions.", "Nu aveţi dreptul să modificaţi drepturile tipului de utilizator");
regGS("Updating user type permissions", "Modific drepturile tipului de utilizator");
regGS("User type permissions have been successfuly updated.", "Drepturile tipului de utilizator au fost modificate");
regGS("User type permissions could not be updated.", "Drepturile tipului de utilizator nu pot fi modificate");
regGS("User type $1 changed permissions", "Drepturile tipului de utilizator $1 au fost modificate");
?>

==> campsite-2.5.1.tar.gz: campsite/implementation/management/priv/lang/ro/user_types.php <==
<?php
regGS("User types", "Tipuri de utilizatori");
regGS("No user types.", "Nu există tipuri de utilizatori");
regGS("Are you sure you want to delete the user type $1?", "Eşti sigur că vrei să ştergi tipul de utilizator $1?");
regGS("No such user type.", "Nu există tipul de utilizator respectiv.");
regGS("You do not have the right to delete user types.", "Nu ai dreptul să ştergi tipuri de utilizatori.");
regGS("User type", "Tipul utilizatorului");
regGS("Change user type permissions", "Modifică drepturile tipului de utilizator");
regGS("You do not have the right to change user type permissions.", "Nu ai dreptul să modifici drepturile tipului de utilizator.");
regGS("User type $1 changed permissions", "Drepturile tipului de utilizator $1 au fost modificate");
regGS("You do not have the right to add user types.", "Nu aveţi dreptul să adăugaţi tipuri de utilizatori");
regGS("Adding new user type", "Adaug tip de utilizator");
regGS("The user type $1 has been added.", "Tipul de utilizator $1 a fost adăugat");
regGS("The user type could not be added.", "Tipul de utilizator $1 nu poate fi adăugat");
regGS("Please check if an user type with the same name does not already exist.", "Verificaţi dacă tipul de utilizator există deja");
regGS("Deleting user type", "Şterg tipul de utilizator");
regGS("The user type has been deleted.", "Tipul de utilizator a fost şters");
regGS("The user type could not be deleted.", "Tipul de utilizator nu poate fi şters");
regGS("Updating user type permissions", "Modific drepturile tipului de utilizator");
regGS("User type permissions have been successfuly updated.", "Drepturile tipului de utilizator au fost modificate");
regGS("User type permissions could not be updated.", "Drepturile tipului de utilizator nu pot fi modificate");
?>
